@@ -59,7 +59,7 @@ impl Lint {
             Lint::PivotalTrackerIdMissing => checks::missing_pivotal_tracker_id::CONFIG,
             Lint::JiraIssueKeyMissing => checks::missing_jira_issue_key::CONFIG,
             Lint::GitHubIdMissing => checks::missing_github_id::CONFIG,
-            Lint::SubjectNotSeparateFromBody => checks::subject_not_seperate_from_body::CONFIG,
+            Lint::SubjectNotSeparateFromBody => checks::subject_not_separate_from_body::CONFIG,
             Lint::SubjectLongerThan72Characters => {
                 checks::subject_longer_than_72_characters::CONFIG
             }
@@ -119,7 +119,7 @@ impl Lint {
             Lint::JiraIssueKeyMissing => checks::missing_jira_issue_key::lint(commit_message),
             Lint::GitHubIdMissing => checks::missing_github_id::lint(commit_message),
             Lint::SubjectNotSeparateFromBody => {
-                checks::subject_not_seperate_from_body::lint(commit_message)
+                checks::subject_not_separate_from_body::lint(commit_message)
             }
             Lint::SubjectLongerThan72Characters => {
                 checks::subject_longer_than_72_characters::lint(commit_message)
@@ -150,8 +150,6 @@ impl Lint {
 mod tests_lints {
     use std::convert::TryInto;
 
-    use pretty_assertions::assert_eq;
-
     use crate::lints::Lint;
 
     #[test]
@@ -197,11 +195,11 @@ mod tests_lints {
 
     #[test]
     fn i_can_get_if_a_lint_is_enabled_by_default() {
-        assert_eq!(Lint::DuplicatedTrailers.enabled_by_default(), true);
-        assert_eq!(Lint::PivotalTrackerIdMissing.enabled_by_default(), false);
-        assert_eq!(Lint::JiraIssueKeyMissing.enabled_by_default(), false);
-        assert_eq!(Lint::SubjectNotSeparateFromBody.enabled_by_default(), true);
-        assert_eq!(Lint::GitHubIdMissing.enabled_by_default(), false);
+        assert!(Lint::DuplicatedTrailers.enabled_by_default());
+        assert!(!Lint::PivotalTrackerIdMissing.enabled_by_default());
+        assert!(!Lint::JiraIssueKeyMissing.enabled_by_default());
+        assert!(Lint::SubjectNotSeparateFromBody.enabled_by_default());
+        assert!(!Lint::GitHubIdMissing.enabled_by_default());
     }
 }
 
